Hemlock-REST
============

Hemlock REST Server.  Same functionality as the [Hemlock CLI](https://github.com/Lab41/Hemlock/blob/master/docs/CLI.md), but through a
[RESTful](https://github.com/Lab41/Hemlock-REST/blob/master/docs/REST.md) interface.

![Hemlock L](https://raw.github.com/Lab41/Hemlock-REST/master/docs/images/logo.png "Hemlock")

Install instructions
====================

```bash
sudo pip install hemlock-rest
```

Required dependencies
---------------------

[Hemlock](http://lab41.github.io/Hemlock/)

Python modules:
- pexpect
- [web](http://webpy.org/)


Running
----------

```bash
hemlock-rest
```
Alternatively, ``hemlock_rest.py`` can be modified to support more robust
webservers.


Related repositories
--------------------

- [Hemlock](http://lab41.github.io/Hemlock/)
- [Hemlock-Frontend](http://lab41.github.io/Hemlock-Frontend/)


Tests
=====

The tests for this project use [py.test](http://pytest.org/latest/)

Travis CI Status
================

[![Build Status](https://travis-ci.org/Lab41/Hemlock-REST.png?branch=master)](https://travis-ci.org/Lab41/Hemlock-REST)


Contributing
============

What to contribute?  Awesome!  Issue a pull request or see more details [here](https://github.com/Lab41/Hemlock-REST/blob/master/CONTRIBUTING.md).
